@@ -156,7 +156,7 @@ typedef KviPointerList<KviRegisteredMask> KviRegisteredMaskList;
 
 class KVILIB_API KviRegisteredUserDataBase : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviRegisteredUserDataBase();
