@@ -660,7 +660,7 @@ void KviApp::contextSensitiveHelp()
 	TQWidget * w = g_pApp->focusWidget();
 	while(w)
 	{
-		//TQVariant v = w->property("contextSensitiveHelp"); <-- this prints a lot of warnings: this is a QT BUG
+		//TQVariant v = w->property("contextSensitiveHelp"); <-- this prints a lot of warnings: this is a TQt BUG
 		TQMetaObject * o = w->metaObject();
 		if(o)
 		{
@@ -700,25 +700,6 @@ void KviApp::loadDefaultScript()
 	g_pFrame->lineUpDockWindows(); // missing on TQt 4.x
 }
 
-// 07.01.2005 06:01: Got this curious gcc error while writing
-//                   the functions below...
-//                   The problem is gone by simply typing make again.
-//                   Memory/Disk transfer error ?
-//
-// if g++ -DHAVE_CONFIG_H -I. -I. -I../../../src  -I/usr/build/kvirccvs/kvirc/src/kvilib/include/ -I/usr/build/kvirccvs/kvirc/src/kvirc/include/ -I/opt/qt/include -I/usr/X11R6/include -I/usr/X11R6/include -I/opt/kde/include -D_REENTRANT -DREENTRANT  -I/usr/X11R6/include -DGLOBAL_KVIRC_DIR=\"/usr/local/share/kvirc/3.0.1.99\"   -g -MT kvi_ircconnection.o -MD -MP -MF ".deps/kvi_ircconnection.Tpo"
-//  -c -o kvi_ircconnection.o `test -f '../kernel/kvi_ircconnection.cpp' || echo './'`../kernel/kvi_ircconnection.cpp;
-// then mv -f ".deps/kvi_ircconnection.Tpo" ".deps/kvi_ircconnection.Po";
-// else rm -f ".deps/kvi_ircconnection.Tpo"; exit 1;
-// fi
-// /opt/qt/include/qstringlist.h:62: sorry, not implemented: `
-//   expr_with_file_location' not supported by dump_decl
-// /opt/qt/include/qstringlist.h: In function `<declaration error>':
-// /opt/qt/include/qstringlist.h:62: internal error: Segmentation fault
-// Please submit a full bug report,
-// with preprocessed source if appropriate.
-// See <URL:http://bugzilla.redhat.com/bugzilla/> for instructions.
-
-
 void KviApp::checkSuggestRestoreDefaultScript()
 {
 	static bool bSuggestedOnce = false;
@@ -1056,7 +1037,7 @@ void KviApp::fileDownloadTerminated(bool bSuccess,const TQString &szRemoteUrl,co
 				delete g_pKdeDesktopBackground;
                 g_pKdeDesktopBackground = 0;
 				// this signal shouldn't be connected ,but well.. let's make sure
-				disconnect(this,TQT_SIGNAL(backgroundChanged(int)),this,TQT_SLOT(kdeRootPixmapChanged(int)));
+				disconnect(this,TQ_SIGNAL(backgroundChanged(int)),this,TQ_SLOT(kdeRootPixmapChanged(int)));
 			}
 			g_pKdeDesktopBackground = 0;
 
@@ -1074,7 +1055,7 @@ void KviApp::fileDownloadTerminated(bool bSuccess,const TQString &szRemoteUrl,co
 		    TQString name = TQString("DESKTOP%1").arg(rinfo.currentDesktop());
 
 			g_pKdeDesktopBackground = new TDESharedPixmap();
-			connect(g_pKdeDesktopBackground,TQT_SIGNAL(done(bool)),this,TQT_SLOT(kdeRootPixmapDownloadComplete(bool)));
+			connect(g_pKdeDesktopBackground,TQ_SIGNAL(done(bool)),this,TQ_SLOT(kdeRootPixmapDownloadComplete(bool)));
 
 		    if(!(g_pKdeDesktopBackground->isAvailable(name)))
 			{
@@ -1091,7 +1072,7 @@ void KviApp::fileDownloadTerminated(bool bSuccess,const TQString &szRemoteUrl,co
 				client->send("kdesktop","KBackgroundIface","setExport(int)",data);
 				m_bUpdatePseudoTransparencyPending = true;
 				// Now wait a while and try again....
-				TQTimer::singleShot(500,this,TQT_SLOT(updatePseudoTransparency()));
+				TQTimer::singleShot(500,this,TQ_SLOT(updatePseudoTransparency()));
 				return;
 			}
 
@@ -1116,7 +1097,7 @@ void KviApp::fileDownloadTerminated(bool bSuccess,const TQString &szRemoteUrl,co
 			g_pKdeDesktopBackground = 0;
 		}
 		// forget the backgroundChanged signal (will do nothing if it is not connected)
-		disconnect(this,TQT_SIGNAL(backgroundChanged(int)),this,TQT_SLOT(kdeRootPixmapChanged(int)));
+		disconnect(this,TQ_SIGNAL(backgroundChanged(int)),this,TQ_SLOT(kdeRootPixmapChanged(int)));
 #endif //COMPILE_TDE_SUPPORT
 		if(g_pShadedParentGlobalDesktopBackground)
 		{
@@ -1134,7 +1115,7 @@ void KviApp::fileDownloadTerminated(bool bSuccess,const TQString &szRemoteUrl,co
 	{
 		if(m_bUpdatePseudoTransparencyPending)return;
 		m_bUpdatePseudoTransparencyPending = true;
-		TQTimer::singleShot(0,this,TQT_SLOT(updatePseudoTransparency()));
+		TQTimer::singleShot(0,this,TQ_SLOT(updatePseudoTransparency()));
 	}
 
 #ifdef COMPILE_TDE_SUPPORT
@@ -1263,9 +1244,9 @@ void KviApp::kdeRootPixmapDownloadComplete(bool bSuccess)
 			// create shaded copies...
 			createGlobalBackgrounds(g_pKdeDesktopBackground);
 			// make sure that this signal is not connected twice
-			disconnect(this,TQT_SIGNAL(backgroundChanged(int)),this,TQT_SLOT(kdeRootPixmapChanged(int)));
+			disconnect(this,TQ_SIGNAL(backgroundChanged(int)),this,TQ_SLOT(kdeRootPixmapChanged(int)));
 			// connect it
-			connect(this,TQT_SIGNAL(backgroundChanged(int)),this,TQT_SLOT(kdeRootPixmapChanged(int)));
+			connect(this,TQ_SIGNAL(backgroundChanged(int)),this,TQ_SLOT(kdeRootPixmapChanged(int)));
 		}
 		delete g_pKdeDesktopBackground;
 		g_pKdeDesktopBackground = 0;
@@ -1308,7 +1289,7 @@ void KviApp::triggerUpdateGui()
 {
 	if(m_bUpdateGuiPending)return;
 	m_bUpdateGuiPending = true;
-	TQTimer::singleShot(0,this,TQT_SLOT(updateGui()));
+	TQTimer::singleShot(0,this,TQ_SLOT(updateGui()));
 }
 
 void KviApp::updateGui()
@@ -2019,7 +2000,7 @@ void KviApp::timerEvent(TQTimerEvent *e)
 	heartbeat(tNow);
 }
 
-// qvariant.h uses this , and it is included by the qt generated moc file for TQt >= 3.0.0
+// qvariant.h uses this , and it is included by the tqt generated moc file for TQt >= 3.0.0
 #ifdef Bool
 	#undef Bool
 #endif
