@@ -554,7 +554,7 @@
 		For example, you can find out if the widget accepts drops by calling [classfnc]$property(acceptDrops)[classfnc].[br]
 		This function will be mainly useful in the [class]wrapper[/class] class.
 		!fn: $setProperty(<TQt property>,<property value>)
-		Sets a qt property for this widget.[br]
+		Sets a tqt property for this widget.[br]
 		This is for advanced scripting, and can control really many features of the TQt widgets.[br]
 		For example, the [class]multilineedit[/class] widgets can be set to
 		the "password" echo mode only by using this function call:[br]
@@ -694,7 +694,7 @@ KviKvsObject::~KviKvsObject()
 
 	if(m_pObject)
 	{
-		disconnect(m_pObject,TQT_SIGNAL(destroyed()),this,TQT_SLOT(objectDestroyed()));
+		disconnect(m_pObject,TQ_SIGNAL(destroyed()),this,TQ_SLOT(objectDestroyed()));
 		if(m_bObjectOwner)delete m_pObject;
 	}
 
@@ -730,7 +730,7 @@ void KviKvsObject::registerChild(KviKvsObject *pChild)
 	m_pChildList->append(pChild);
 }
 
-// SIGNAL/TQT_SLOT stuff
+// TQ_SIGNAL/TQ_SLOT stuff
 
 bool KviKvsObject::connectSignal(const TQString &sigName,KviKvsObject * pTarget,const TQString &slotName)
 {
@@ -1517,7 +1517,7 @@ bool KviKvsObject::die()
 {
 	if(m_bInDelayedDeath)return false;
 	m_bInDelayedDeath = true;
-	TQTimer::singleShot(0,this,TQT_SLOT(delayedDie()));
+	TQTimer::singleShot(0,this,TQ_SLOT(delayedDie()));
 	return true;
 }
 
@@ -1540,7 +1540,7 @@ void KviKvsObject::setObject(TQObject * o,bool bIsOwned)
 	m_bObjectOwner = bIsOwned;
 	m_pObject = o;
 	o->installEventFilter(this);
-	connect(m_pObject,TQT_SIGNAL(destroyed()),this,TQT_SLOT(objectDestroyed()));
+	connect(m_pObject,TQ_SIGNAL(destroyed()),this,TQ_SLOT(objectDestroyed()));
 }
 
 void KviKvsObject::objectDestroyed()
