@@ -285,7 +285,7 @@ KviKvsPopupMenuItemLabel::~KviKvsPopupMenuItemLabel()
 {
 	if(m_pLabel)
 	{
-		TQObject::disconnect(m_pLabel,TQT_SIGNAL(destroyed()),m_pSignalRelay,TQT_SLOT(labelDestroyed()));
+		TQObject::disconnect(m_pLabel,TQ_SIGNAL(destroyed()),m_pSignalRelay,TQ_SLOT(labelDestroyed()));
 		delete m_pLabel;
 	}
 	delete m_pSignalRelay;
@@ -293,7 +293,7 @@ KviKvsPopupMenuItemLabel::~KviKvsPopupMenuItemLabel()
 
 void KviKvsPopupMenuItemLabel::labelDestroyed()
 {
-	m_pLabel = 0; // someone (maybe qt, maybe us) has destroyed the label
+	m_pLabel = 0; // someone (maybe tqt, maybe us) has destroyed the label
 }
 
 
@@ -306,7 +306,7 @@ void KviKvsPopupMenuItemLabel::clear()
 {
 	if(m_pLabel)
 	{
-		TQObject::disconnect(m_pLabel,TQT_SIGNAL(destroyed()),m_pSignalRelay,TQT_SLOT(labelDestroyed()));
+		TQObject::disconnect(m_pLabel,TQ_SIGNAL(destroyed()),m_pSignalRelay,TQ_SLOT(labelDestroyed()));
 		delete m_pLabel;
 		m_pLabel = 0;
 	}
@@ -319,15 +319,12 @@ void KviKvsPopupMenuItemLabel::fill(KviKvsPopupMenu * pMenu,KviKvsPopupMenuTopLe
 	TQPixmap * pPix = evaluateIcon(pData);
 	if(m_pLabel)
 	{
-		TQObject::disconnect(m_pLabel,TQT_SIGNAL(destroyed()),m_pSignalRelay,TQT_SLOT(labelDestroyed()));
+		TQObject::disconnect(m_pLabel,TQ_SIGNAL(destroyed()),m_pSignalRelay,TQ_SLOT(labelDestroyed()));
 		delete m_pLabel;
 	}
 	m_pLabel = new TQLabel(szText,pMenu);
-	TQObject::connect(m_pLabel,TQT_SIGNAL(destroyed()),m_pSignalRelay,TQT_SLOT(labelDestroyed()));
-#ifndef COMPILE_USE_QT4
-	// FIXME: QT4 Seems to not allow widgets as TQMenu items
+	TQObject::connect(m_pLabel,TQ_SIGNAL(destroyed()),m_pSignalRelay,TQ_SLOT(labelDestroyed()));
 	pMenu->insertItem(m_pLabel);
-#endif
 	m_pLabel->setFrameStyle(TQFrame::StyledPanel | TQFrame::Raised);
 	if(pPix)m_pLabel->setPixmap(*pPix);
 }
@@ -541,8 +538,8 @@ KviKvsPopupMenu::KviKvsPopupMenu(const TQString &szName)
 	m_pTopLevelData = 0;
 	m_pTempTopLevelData = 0;
 	m_bSetupDone = false;
-	connect(this,TQT_SIGNAL(activated(int)),this,TQT_SLOT(itemClicked(int)));
-	connect(this,TQT_SIGNAL(aboutToShow()),this,TQT_SLOT(setupMenuContents()));
+	connect(this,TQ_SIGNAL(activated(int)),this,TQ_SLOT(itemClicked(int)));
+	connect(this,TQ_SIGNAL(aboutToShow()),this,TQ_SLOT(setupMenuContents()));
 }
 
 
