@@ -80,11 +80,7 @@ bool KviKvsProcessAsyncOperation::start()
 			//
 			// [02:50:21] <kode54> if ( TQApplication::winVersion() & TQt::WV_NT_based )
 			// [02:50:41] <kode54> I see another implementation using that, maybe it is the official way of detecting that :[
-#ifdef COMPILE_USE_QT4
-			szShell = !(TQSysInfo::WindowsVersion & TQSysInfo::WV_DOS_based) ? "cmd.exe /c" : "command.com /c";
-#else
 			szShell = "command.com /c";
-#endif
 
 			// Thnx kode54 :)
 #else
@@ -100,19 +96,19 @@ bool KviKvsProcessAsyncOperation::start()
 	
 	if(m_pData->iFlags & KVI_KVS_PROCESSDESCRIPTOR_TRIGGERSTDOUT)
 	{
-		connect(m_pProcess,TQT_SIGNAL(readyReadStdout()),this,TQT_SLOT(readStdout()));
+		connect(m_pProcess,TQ_SIGNAL(readyReadStdout()),this,TQ_SLOT(readStdout()));
 		c |= KviProcess::Stdout;
 	}
 	
 	if(m_pData->iFlags & KVI_KVS_PROCESSDESCRIPTOR_TRIGGERSTDERR)
 	{
-		connect(m_pProcess,TQT_SIGNAL(readyReadStderr()),this,TQT_SLOT(readStderr()));
+		connect(m_pProcess,TQ_SIGNAL(readyReadStderr()),this,TQ_SLOT(readStderr()));
 		c |= KviProcess::Stderr;
 	}
 
 	m_pProcess->setCommunication(c);
 	
-	connect(m_pProcess,TQT_SIGNAL(processExited()),this,TQT_SLOT(processExited()));
+	connect(m_pProcess,TQ_SIGNAL(processExited()),this,TQ_SLOT(processExited()));
 	
 	if(!m_pProcess->start())
 	{
@@ -133,14 +129,14 @@ bool KviKvsProcessAsyncOperation::start()
 	if(m_pData->iMaxRunTime > 0)
 	{
 		m_pRunTimeTimer = new TQTimer(this);
-		connect(m_pRunTimeTimer,TQT_SIGNAL(timeout()),this,TQT_SLOT(maxRunTimeExpired()));
+		connect(m_pRunTimeTimer,TQ_SIGNAL(timeout()),this,TQ_SLOT(maxRunTimeExpired()));
 		m_pRunTimeTimer->start(m_pData->iMaxRunTime);
 	}
 	
 	if(m_pData->iPingTimeout > 0)
 	{
 		m_pPingTimer = new TQTimer(this);
-		connect(m_pPingTimer,TQT_SIGNAL(timeout()),this,TQT_SLOT(ping()));
+		connect(m_pPingTimer,TQ_SIGNAL(timeout()),this,TQ_SLOT(ping()));
 		m_pPingTimer->start(m_pData->iPingTimeout);
 	}
 	
@@ -159,7 +155,7 @@ void KviKvsProcessAsyncOperation::triggerSelfDelete()
 {
 	if(m_bDeletePending)return;
 	m_bDeletePending = true;
-	TQTimer::singleShot(m_pData->iMaxRunTime,this,TQT_SLOT(selfDelete()));
+	TQTimer::singleShot(m_pData->iMaxRunTime,this,TQ_SLOT(selfDelete()));
 }
 
 void KviKvsProcessAsyncOperation::selfDelete()
