@@ -201,7 +201,7 @@ KviInputEditor::KviInputEditor(TQWidget * par,KviWindow *wnd,KviUserListView * v
 	setFrameShadow( Plain );
 	
 	m_pIconMenu = new KviTalPopupMenu();
-	connect(m_pIconMenu,TQT_SIGNAL(activated(int)),this,TQT_SLOT(iconPopupActivated(int)));
+	connect(m_pIconMenu,TQ_SIGNAL(activated(int)),this,TQ_SLOT(iconPopupActivated(int)));
 
 	setCursor(IbeamCursor);
 }
@@ -292,7 +292,7 @@ TQSize KviInputEditor::sizeHint() const
 	int h = TQMAX(fm.lineSpacing(), 14) + 2*2; /* innerMargin */
 	int w = fm.width( 'x' ) * 17; // "some"
 	int m = frameWidth() * 2;
-	return (style().tqsizeFromContents(TQStyle::CT_LineEdit, this,
+	return (style().sizeFromContents(TQStyle::CT_LineEdit, this,
 				     TQSize( w + m, h + m ).
 				     expandedTo(TQApplication::globalStrut())));
 }
@@ -719,7 +719,7 @@ void KviInputEditor::runUpToTheFirstVisibleChar()
 
 void KviInputEditor::mousePressEvent(TQMouseEvent *e)
 {
-	if(e->button() & Qt::LeftButton)
+	if(e->button() & TQt::LeftButton)
 	{
 		m_iCursorPosition = charIndexFromXPosition(e->pos().x());
 		//move the cursor to
@@ -732,7 +732,7 @@ void KviInputEditor::mousePressEvent(TQMouseEvent *e)
 		killDragTimer();
 		m_iDragTimer = startTimer(KVI_INPUT_DRAG_TIMEOUT);
 
-	} else if(e->button() & Qt::RightButton)
+	} else if(e->button() & TQt::RightButton)
 	{
         int type = g_pActiveWindow->type();
 
@@ -782,30 +782,30 @@ void KviInputEditor::mousePressEvent(TQMouseEvent *e)
 			}
 		}
 		
-		int id = g_pInputPopup->insertItem(__tr2qs("Cu&t") + ACCEL_KEY(X),this,TQT_SLOT(cut()));
+		int id = g_pInputPopup->insertItem(__tr2qs("Cu&t") + ACCEL_KEY(X),this,TQ_SLOT(cut()));
 		g_pInputPopup->setItemEnabled(id,hasSelection());
-		id = g_pInputPopup->insertItem(__tr2qs("&Copy") + ACCEL_KEY(C),this,TQT_SLOT(copyToClipboard()));
+		id = g_pInputPopup->insertItem(__tr2qs("&Copy") + ACCEL_KEY(C),this,TQ_SLOT(copyToClipboard()));
 		g_pInputPopup->setItemEnabled(id,hasSelection());
-		id = g_pInputPopup->insertItem(__tr2qs("&Paste") + ACCEL_KEY(V),this,TQT_SLOT(pasteClipboardWithConfirmation()));
+		id = g_pInputPopup->insertItem(__tr2qs("&Paste") + ACCEL_KEY(V),this,TQ_SLOT(pasteClipboardWithConfirmation()));
 		g_pInputPopup->setItemEnabled(id,!szClip.isEmpty() && !m_bReadOnly);
-		id = g_pInputPopup->insertItem(__tr2qs("Paste (Slowly)"),this,TQT_SLOT(pasteSlow()));
+		id = g_pInputPopup->insertItem(__tr2qs("Paste (Slowly)"),this,TQ_SLOT(pasteSlow()));
 		if ((type == KVI_WINDOW_TYPE_CHANNEL) || (type == KVI_WINDOW_TYPE_QUERY) || (type == KVI_WINDOW_TYPE_DCCCHAT))
 			g_pInputPopup->setItemEnabled(id,!szClip.isEmpty() && !m_bReadOnly);
 		else 
 			g_pInputPopup->setItemEnabled(id,false);
-		id = g_pInputPopup->insertItem(__tr2qs("Paste &File") + ACCEL_KEY(F),this,TQT_SLOT(pasteFile()));
+		id = g_pInputPopup->insertItem(__tr2qs("Paste &File") + ACCEL_KEY(F),this,TQ_SLOT(pasteFile()));
 		if ((type != KVI_WINDOW_TYPE_CHANNEL) && (type != KVI_WINDOW_TYPE_QUERY) && (type != KVI_WINDOW_TYPE_DCCCHAT))
 			g_pInputPopup->setItemEnabled(id,false);
 		else
 			g_pInputPopup->setItemEnabled(id,!m_bReadOnly);
 		if(m_bSpSlowFlag ==true)
 		{
-			id = g_pInputPopup->insertItem(__tr2qs("Stop Paste"),this,TQT_SLOT(stopPasteSlow())); /*G&N 2005*/
+			id = g_pInputPopup->insertItem(__tr2qs("Stop Paste"),this,TQ_SLOT(stopPasteSlow())); /*G&N 2005*/
 		}
-		id = g_pInputPopup->insertItem(__tr2qs("Clear"),this,TQT_SLOT(clear()));
+		id = g_pInputPopup->insertItem(__tr2qs("Clear"),this,TQ_SLOT(clear()));
 		g_pInputPopup->setItemEnabled(id,!m_szTextBuffer.isEmpty() && !m_bReadOnly);
 		g_pInputPopup->insertSeparator();
-		id = g_pInputPopup->insertItem(__tr2qs("Select All"),this,TQT_SLOT(selectAll()));
+		id = g_pInputPopup->insertItem(__tr2qs("Select All"),this,TQ_SLOT(selectAll()));
 		g_pInputPopup->setItemEnabled(id,(!m_szTextBuffer.isEmpty()));
 		
 		
@@ -2234,7 +2234,7 @@ KviInput::KviInput(KviWindow *par,KviUserListView * view)
 	if(g_pIconManager->getBigIcon("kvi_horizontal_left.png"))
 		m_pHideToolsButton->setPixmap(*(g_pIconManager->getBigIcon("kvi_horizontal_left.png")));
 	
-	connect(m_pHideToolsButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(toggleToolButtons()));
+	connect(m_pHideToolsButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(toggleToolButtons()));
 	
 	m_pButtonContainer=new KviTalHBox(this);
 	m_pButtonContainer->setSpacing(0);
@@ -2249,7 +2249,7 @@ KviInput::KviInput(KviWindow *par,KviUserListView * view)
 		is1.setPixmap(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TIME)),TQIconSet::Small);
 		m_pHistoryButton->setIconSet(is1);
 		KviTalToolTip::add(m_pHistoryButton,__tr2qs("Show History<br>&lt;Ctrl+PageUp&gt;"));
-		connect(m_pHistoryButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(historyButtonClicked()));
+		connect(m_pHistoryButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(historyButtonClicked()));
 	}
 	else
 	{
@@ -2265,7 +2265,7 @@ KviInput::KviInput(KviWindow *par,KviUserListView * view)
 	m_pIconButton->setIconSet(is3);
 	KviTalToolTip::add(m_pIconButton,__tr2qs("Show Icons Popup<br>&lt;Ctrl+I&gt;<br>See also /help texticons"));
 
-	connect(m_pIconButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(iconButtonClicked()));
+	connect(m_pIconButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(iconButtonClicked()));
 
 
 	m_pCommandlineModeButton = new KviStyledToolButton(m_pButtonContainer,"commandlinemodebutton");
@@ -2291,10 +2291,10 @@ KviInput::KviInput(KviWindow *par,KviUserListView * view)
 	szTip += " - &lt;Ctrl+Backspace&gt;";
 	KviTalToolTip::add(m_pMultiEditorButton,szTip);
 
-	connect(m_pMultiEditorButton,TQT_SIGNAL(toggled(bool)),this,TQT_SLOT(multilineEditorButtonToggled(bool)));
+	connect(m_pMultiEditorButton,TQ_SIGNAL(toggled(bool)),this,TQ_SLOT(multilineEditorButtonToggled(bool)));
 	
 	m_pInputEditor = new KviInputEditor(this,par,view);
-	connect(m_pInputEditor,TQT_SIGNAL(enterPressed()),this,TQT_SLOT(inputEditorEnterPressed()));
+	connect(m_pInputEditor,TQ_SIGNAL(enterPressed()),this,TQ_SLOT(inputEditorEnterPressed()));
 	m_pInputEditor->setSizePolicy(TQSizePolicy(TQSizePolicy::Ignored,TQSizePolicy::Ignored));
 	
 
@@ -2527,7 +2527,7 @@ void KviInput::applyOptions()
 		is1.setPixmap(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_QUITSPLIT)),TQIconSet::Small);
 		m_pHistoryButton->setIconSet(is1);
 		KviTalToolTip::add(m_pHistoryButton,__tr2qs("Input History Disabled"));
-		m_pHistoryButton->disconnect(TQT_SIGNAL(clicked()));
+		m_pHistoryButton->disconnect(TQ_SIGNAL(clicked()));
 	}
 
 	if(!KVI_OPTION_BOOL(KviOption_boolDisableInputHistory))
@@ -2536,7 +2536,7 @@ void KviInput::applyOptions()
 		is1.setPixmap(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TIME)),TQIconSet::Small);
 		m_pHistoryButton->setIconSet(is1);
 		KviTalToolTip::add(m_pHistoryButton,__tr2qs("Show History<br>&lt;Ctrl+PageUp&gt;"));
-		connect(m_pHistoryButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(historyButtonClicked()));
+		connect(m_pHistoryButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(historyButtonClicked()));
 	}
 
 	m_pInputEditor->applyOptions();
