@@ -183,7 +183,7 @@ void KviListView::resizeEvent(TQResizeEvent * e)
 {
 	KviTalListView::resizeEvent(e);
 	if(m_pBackgroundOverlayPixmap)
-	repaintContents(); // force a full repaint (otherwise qt does not honor static background here)
+	repaintContents(); // force a full repaint (otherwise tqt does not honor static background here)
 }
 
 #ifdef COMPILE_ON_WINDOWS
