@@ -59,7 +59,7 @@ void KviModeWidget::reset()
 		m_pLabel=new KviThemedLabel(this,0);
 	refreshModes();
 	m_pLabel->show();
-	connect(m_pLabel,TQT_SIGNAL(doubleClicked()),this,TQT_SLOT(labelDoubleClick()));
+	connect(m_pLabel,TQ_SIGNAL(doubleClicked()),this,TQ_SLOT(labelDoubleClick()));
 	TQResizeEvent* ev=new TQResizeEvent(size(),size());
 	resizeEvent(ev);
 	delete ev;
@@ -109,7 +109,7 @@ void KviModeWidget::labelDoubleClick()
 		m_pLineEdit->setFocus();
 		resizeEvent(new TQResizeEvent(size(),size()));
 		m_pLineEdit->installEventFilter( this );
-		connect(m_pLineEdit,TQT_SIGNAL(textChanged ( const TQString & ) ),this,TQT_SLOT(editorTextChanged( const TQString & )));
+		connect(m_pLineEdit,TQ_SIGNAL(textChanged ( const TQString & ) ),this,TQ_SLOT(editorTextChanged( const TQString & )));
 	}
 }
 
