@@ -79,20 +79,20 @@ KviQuery::KviQuery(KviFrame * lpFrm,KviConsole * lpConsole,const TQString &nick)
 	// The button box on the right
 	//KviTalHBox * box = new KviTalHBox(m_pTopSplitter,"button_box");
 	if(KVI_OPTION_BOOL(KviOption_boolShowExtendedInfoInQueryLabel))
-		m_pButtonGrid= (TQFrame*) new KviTalGrid(2,Qt::Horizontal,m_pButtonBox);
+		m_pButtonGrid= (TQFrame*) new KviTalGrid(2,TQt::Horizontal,m_pButtonBox);
 	else
-		m_pButtonGrid= (TQFrame*) new KviTalGrid(4,Qt::Horizontal,m_pButtonBox);
+		m_pButtonGrid= (TQFrame*) new KviTalGrid(4,TQt::Horizontal,m_pButtonBox);
 
 	createTextEncodingButton(m_pButtonGrid);
 
-	m_pSplitter = new TQSplitter(Qt::Horizontal,this,"main_splitter");
+	m_pSplitter = new TQSplitter(TQt::Horizontal,this,"main_splitter");
 	m_pIrcView = new KviIrcView(m_pSplitter,lpFrm,this);
-	connect(m_pIrcView,TQT_SIGNAL(rightClicked()),this,TQT_SLOT(textViewRightClicked()));
+	connect(m_pIrcView,TQ_SIGNAL(rightClicked()),this,TQ_SLOT(textViewRightClicked()));
 	//m_pEditorsContainer= new KviToolWindowsContainer(m_pSplitter);
 		
 		
 	m_pListViewButton = new KviWindowToolPageButton(KVI_SMALLICON_HIDELISTVIEW,KVI_SMALLICON_SHOWLISTVIEW,__tr2qs("Show User List"),buttonContainer(),true,"list_view_button");
-	connect(m_pListViewButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(toggleListView()));
+	connect(m_pListViewButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(toggleListView()));
 	
 #ifdef COMPILE_CRYPT_SUPPORT
 	createCryptControllerButton(m_pButtonGrid);
@@ -106,7 +106,7 @@ KviQuery::KviQuery(KviFrame * lpFrm,KviConsole * lpConsole,const TQString &nick)
 	// FIXME: #warning "Maybe tell the user all that we know about the remote end(s)....channels..."
 
 	m_pIrcView->enableDnd(TRUE);
-	connect(m_pIrcView,TQT_SIGNAL(fileDropped(const char *)),this,TQT_SLOT(slotDndEvents(const char *)));
+	connect(m_pIrcView,TQ_SIGNAL(fileDropped(const char *)),this,TQ_SLOT(slotDndEvents(const char *)));
 	
 	updateCaption();
 }
