@@ -222,7 +222,7 @@ KviPixmapSelector::KviPixmapSelector(TQWidget * par,const TQString & txt,KviPixm
 
 	m_pCheckBox = new KviStyledCheckBox(txt,this);
 	m_pCheckBox->setChecked(m_localPixmap.pixmap());
-	connect(m_pCheckBox,TQT_SIGNAL(toggled(bool)),this,TQT_SLOT(checkBoxToggled(bool)));
+	connect(m_pCheckBox,TQ_SIGNAL(toggled(bool)),this,TQ_SLOT(checkBoxToggled(bool)));
 	g->addMultiCellWidget(m_pCheckBox,0,0,0,1);
 
 	m_pPreview = new KviPixmapPreview(this);
@@ -236,7 +236,7 @@ KviPixmapSelector::KviPixmapSelector(TQWidget * par,const TQString & txt,KviPixm
 
 	m_pChooseButton = new TQPushButton("...",this);
 	g->addWidget(m_pChooseButton,2,1);
-	connect(m_pChooseButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(choosePixmap()));
+	connect(m_pChooseButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(choosePixmap()));
 
 	g->setRowStretch(1,1);
 	g->setColStretch(0,1);
@@ -314,7 +314,7 @@ KviFileSelector::KviFileSelector(TQWidget * par,const TQString & txt,TQString *
 	//m_pLineEdit->setMinimumWidth(200);
 	m_pLineEdit->setText(*pOption);
 	m_pButton = new TQPushButton(__tr2qs("&Browse..."),this);
-	connect(m_pButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(browseClicked()));
+	connect(m_pButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(browseClicked()));
 
 	setSpacing(4);
 	setStretchFactor(m_pLineEdit,1);
@@ -399,17 +399,17 @@ KviStringListSelector::KviStringListSelector(TQWidget * par,const TQString & txt
 	m_pLabel = new TQLabel(txt,this);
 	m_pListBox = new KviTalListBox(this);
 	m_pLineEdit = new TQLineEdit(this);
-	connect(m_pLineEdit,TQT_SIGNAL(textChanged(const TQString &)),this,TQT_SLOT(textChanged(const TQString &)));
-	connect(m_pLineEdit,TQT_SIGNAL(returnPressed()),this,TQT_SLOT(addClicked()));
+	connect(m_pLineEdit,TQ_SIGNAL(textChanged(const TQString &)),this,TQ_SLOT(textChanged(const TQString &)));
+	connect(m_pLineEdit,TQ_SIGNAL(returnPressed()),this,TQ_SLOT(addClicked()));
 	KviTalHBox * hBox = new KviTalHBox(this);
 	m_pAddButton = new TQPushButton(__tr2qs("A&dd"),hBox);
-	connect(m_pAddButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(addClicked()));
+	connect(m_pAddButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(addClicked()));
 	m_pRemoveButton = new TQPushButton(__tr2qs("Re&move"),hBox);
-	connect(m_pRemoveButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(removeClicked()));
+	connect(m_pRemoveButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(removeClicked()));
 	m_pOption = pOption;
 	m_pListBox->insertStringList(*pOption);
 	m_pListBox->setSelectionMode(KviTalListBox::Extended);
-	connect(m_pListBox,TQT_SIGNAL(selectionChanged()),this,TQT_SLOT(selectionChanged()));
+	connect(m_pListBox,TQ_SIGNAL(selectionChanged()),this,TQ_SLOT(selectionChanged()));
 	setSpacing(4);
 	setStretchFactor(m_pListBox,1);
 	setEnabled(bEnabled);
@@ -499,7 +499,7 @@ KviColorSelector::KviColorSelector(TQWidget * par,const TQString & txt,TQColor *
 
 	m_pButton = new TQPushButton(" ",this);
 	// m_pButton->setMinimumWidth(150);
-	connect(m_pButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(changeClicked()));
+	connect(m_pButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(changeClicked()));
 
 	setSpacing(4);
 	setStretchFactor(m_pLabel,1);
@@ -553,7 +553,7 @@ KviFontSelector::KviFontSelector(TQWidget * par,const TQString & txt,TQFont * pO
 
 	m_pButton = new TQPushButton("",this);
 	// m_pButton->setMinimumWidth(150);
-	connect(m_pButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(changeClicked()));
+	connect(m_pButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(changeClicked()));
 
 	setSpacing(4);
 	setStretchFactor(m_pLabel,1);
@@ -601,7 +601,7 @@ KviMircTextColorSelector::KviMircTextColorSelector(TQWidget * par,const TQString
 
 	m_pButton = new TQPushButton(__tr2qs("Sample Text"),this);
 	// m_pButton->setMinimumWidth(150);
-	connect(m_pButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(buttonClicked()));
+	connect(m_pButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(buttonClicked()));
 
 	setSpacing(4);
 	setStretchFactor(m_pLabel,1);
@@ -619,7 +619,7 @@ KviMircTextColorSelector::KviMircTextColorSelector(TQWidget * par,const TQString
 	m_pContextPopup = new KviTalPopupMenu(this);
 	
 	m_pForePopup = new KviTalPopupMenu(this);
-	connect(m_pForePopup,TQT_SIGNAL(activated(int)),this,TQT_SLOT(foreSelected(int)));
+	connect(m_pForePopup,TQ_SIGNAL(activated(int)),this,TQ_SLOT(foreSelected(int)));
 	int i;
 	for(i=0;i<KVI_MIRCCOLOR_MAX_FOREGROUND;i++)
 	{
@@ -631,7 +631,7 @@ KviMircTextColorSelector::KviMircTextColorSelector(TQWidget * par,const TQString
 	m_pContextPopup->insertItem(__tr2qs("Foreground"),m_pForePopup);
 
 	m_pBackPopup = new KviTalPopupMenu(this);
-	connect(m_pBackPopup,TQT_SIGNAL(activated(int)),this,TQT_SLOT(backSelected(int)));
+	connect(m_pBackPopup,TQ_SIGNAL(activated(int)),this,TQ_SLOT(backSelected(int)));
 	i = m_pBackPopup->insertItem(__tr2qs("Transparent"));
 	m_pBackPopup->setItemParameter(i,KVI_TRANSPARENT);
 	for(i=0;i<KVI_MIRCCOLOR_MAX_BACKGROUND;i++)
@@ -705,7 +705,7 @@ KviSoundSelector::KviSoundSelector(TQWidget * par,const TQString & txt,TQString
 :KviFileSelector(par,txt,pOption,bEnabled)
 {
 	m_pPlayButton =  new TQPushButton(__tr2qs("Play"),this);
-	connect(m_pPlayButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(playSound()));
+	connect(m_pPlayButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(playSound()));
 }
 
 KviSoundSelector::~KviSoundSelector()
@@ -743,20 +743,20 @@ KviCahnnelListSelector::KviCahnnelListSelector(TQWidget * par,const TQString & t
 	KviTalHBox* pEditsHBox = new KviTalHBox(this);
 	
 	m_pChanLineEdit = new TQLineEdit(pEditsHBox);
-	connect(m_pChanLineEdit,TQT_SIGNAL(textChanged(const TQString &)),this,TQT_SLOT(textChanged(const TQString &)));
-	connect(m_pChanLineEdit,TQT_SIGNAL(returnPressed()),this,TQT_SLOT(addClicked()));
+	connect(m_pChanLineEdit,TQ_SIGNAL(textChanged(const TQString &)),this,TQ_SLOT(textChanged(const TQString &)));
+	connect(m_pChanLineEdit,TQ_SIGNAL(returnPressed()),this,TQ_SLOT(addClicked()));
 	
 	m_pPassLineEdit = new TQLineEdit(pEditsHBox);
 	m_pPassLineEdit->setEchoMode(TQLineEdit::Password);
-	connect(m_pPassLineEdit,TQT_SIGNAL(textChanged(const TQString &)),this,TQT_SLOT(textChanged(const TQString &)));
-	connect(m_pPassLineEdit,TQT_SIGNAL(returnPressed()),this,TQT_SLOT(addClicked()));
+	connect(m_pPassLineEdit,TQ_SIGNAL(textChanged(const TQString &)),this,TQ_SLOT(textChanged(const TQString &)));
+	connect(m_pPassLineEdit,TQ_SIGNAL(returnPressed()),this,TQ_SLOT(addClicked()));
 	
 	
 	KviTalHBox * hBox = new KviTalHBox(this);
 	m_pAddButton = new TQPushButton(__tr2qs("A&dd"),hBox);
-	connect(m_pAddButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(addClicked()));
+	connect(m_pAddButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(addClicked()));
 	m_pRemoveButton = new TQPushButton(__tr2qs("Re&move"),hBox);
-	connect(m_pRemoveButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(removeClicked()));
+	connect(m_pRemoveButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(removeClicked()));
 	m_pOption = pOption;
 	
 	for ( TQStringList::Iterator it = pOption->begin(); it != pOption->end(); ++it ) {
@@ -765,7 +765,7 @@ KviCahnnelListSelector::KviCahnnelListSelector(TQWidget * par,const TQString & t
 
 	m_pListView->setSelectionMode(KviTalListView::Extended);
 	m_pListView->setAllColumnsShowFocus(TRUE);
-	connect(m_pListView,TQT_SIGNAL(selectionChanged()),this,TQT_SLOT(selectionChanged()));
+	connect(m_pListView,TQ_SIGNAL(selectionChanged()),this,TQ_SLOT(selectionChanged()));
 	setSpacing(4);
 	setStretchFactor(m_pListView,1);
 	setEnabled(bEnabled);
