@@ -55,16 +55,9 @@
 #include "kvi_tal_popupmenu.h"
 #include <tqcursor.h>
 
-#ifdef COMPILE_USE_QT4
-	#include <tq3header.h>
-#else
 	#include <tqheader.h>
-#endif
 #include <tqevent.h>
 
-#ifdef COMPILE_USE_QT4
-	#include <TQPaintEvent>
-#endif
 
 
 #ifdef COMPILE_PSEUDO_TRANSPARENCY
@@ -80,19 +73,11 @@ extern TQPixmap * g_pActivityMeterPixmap;
 //
 
 KviTaskBarBase::KviTaskBarBase()
-#ifdef COMPILE_USE_QT4
-: TQDockWidget(__tr2qs("Taskbar"),g_pFrame)
-#else
 : KviToolBar(__tr2qs("Taskbar"),TQT_DOCK_BOTTOM,false,"taskbar")
-#endif
 {
 	// FIXME: this timer should be started only if KVI_OPTION_BOOL(KviOption_boolUseTaskBarActivityMeter)
-#ifdef COMPILE_USE_QT4
-	setObjectName(__tr2qs("taskbar"));
-	setFeatures(TQDockWidget::DockWidgetMovable);
-#endif //COMPILE_USE_QT4
 	m_pActivityMeterTimer = new TQTimer();
-	connect(m_pActivityMeterTimer,TQT_SIGNAL(timeout()),this,TQT_SLOT(updateActivityMeter()));
+	connect(m_pActivityMeterTimer,TQ_SIGNAL(timeout()),this,TQ_SLOT(updateActivityMeter()));
 	m_pActivityMeterTimer->start(5000);
 }
 
@@ -199,7 +184,7 @@ KviTaskBarButton::KviTaskBarButton(TQWidget * par,KviWindow * wnd,const char * n
 {
 	m_bActive         = false;
 	m_pTip            = new KviDynamicToolTip(this);
-	connect(m_pTip,TQT_SIGNAL(tipRequest(KviDynamicToolTip *,const TQPoint &)),this,TQT_SLOT(tipRequest(KviDynamicToolTip *,const TQPoint &)));
+	connect(m_pTip,TQ_SIGNAL(tipRequest(KviDynamicToolTip *,const TQPoint &)),this,TQ_SLOT(tipRequest(KviDynamicToolTip *,const TQPoint &)));
 //	setBackgroundMode(TQWidget::NoBackground);
 	setToggleButton (true);
 	setFlat ( KVI_OPTION_BOOL(KviOption_boolUseFlatClassicTaskbarButtons) );
@@ -222,7 +207,7 @@ void KviTaskBarButton::tipRequest(KviDynamicToolTip *,const TQPoint &pnt)
 
 void KviTaskBarButton::mousePressEvent(TQMouseEvent *e)
 {
-	if(e->button() & Qt::LeftButton)
+	if(e->button() & TQt::LeftButton)
 	{
 		if(e->state() & TQt::ShiftButton)
 		{
@@ -258,18 +243,6 @@ void KviTaskBarButton::setActive(bool bActive)
 	update();
 }
 
-#ifdef COMPILE_USE_QT4
-void KviTaskBarButton::paintEvent(TQPaintEvent * e)
-{
-	TQPainter p(this);
-	TQStyleOption opt;
-	opt.initFrom(this);
-	if(isOn())
-		opt.state = TQStyle::State_On | TQStyle::State_Active;
-	style()->drawPrimitive(TQStyle::PE_PanelButtonTool,&opt,&p,this);
-	drawButtonLabel(&p);
-}
-#endif
 
 void KviTaskBarButton::drawButtonLabel(TQPainter * painter)
 {
@@ -278,15 +251,11 @@ void KviTaskBarButton::drawButtonLabel(TQPainter * painter)
 	int iWidth = distRect.width();
 
 	TQPainter * pPainter;
-#ifdef COMPILE_USE_QT4
-	pPainter = painter;
-#else //!COMPILE_USE_QT4
 	KviDoubleBuffer db(iWidth,iHeight);
 	TQPixmap * pMemBuffer = db.pixmap();
 	TQPainter p(pMemBuffer);
 	bitBlt(pMemBuffer,0,0,painter->device(),distRect.x(),distRect.y(),iWidth,iHeight);
 	pPainter = &p;
-#endif //!COMPILE_USE_QT4
 	if(KVI_OPTION_BOOL(KviOption_boolUseTaskBarIrcContextIndicator))
 	{
 		iHeight -= KVI_TASKBARBUTTON_CONTEXTINDICATORHEIGHT;
@@ -405,10 +374,8 @@ void KviTaskBarButton::drawButtonLabel(TQPainter * painter)
 		cRect.setWidth(cRect.width() + 10);
 		pPainter->drawText(cRect,TQt::AlignLeft | TQt::AlignTop,szText,-1);
 	}
-#ifndef COMPILE_USE_QT4
 	pPainter->setClipping(FALSE);
 	painter->drawPixmap(0,0,*pMemBuffer,distRect.x(),distRect.y(),iWidth,iHeight);
-#endif
 }
 
 
@@ -479,27 +446,18 @@ KviClassicTaskBar::KviClassicTaskBar()
 
 	m_pBase = new TQWidget(this);
 //	m_pBase->setBackgroundMode(NoBackground);
-#ifdef COMPILE_USE_QT4
-	setWidget(m_pBase);
-
-	m_pBase->setMinimumWidth(KVI_TASKBAR_MIN_WIDTH);
-	setMinimumWidth(KVI_TASKBAR_MIN_WIDTH);
-#else //!COMPILE_USE_QT4
 	setStretchableWidget(m_pBase);
 
 	setVerticalStretchable(true);
 	setHorizontalStretchable(true);
-#endif //!COMPILE_USE_QT4
 	//m_pBase->setMinimumWidth(KVI_TASKBAR_MIN_WIDTH);
 	//setMinimumWidth(KVI_TASKBAR_MIN_WIDTH);
 
 	m_pBase->setMinimumHeight(m_iButtonHeight+5);
 	setMinimumHeight(m_iButtonHeight+5);
 	
-#ifndef COMPILE_USE_QT4
 	setResizeEnabled( true );
-	connect(this,TQT_SIGNAL(orientationChanged(Qt::Orientation)),this,TQT_SLOT(orientationChangedSlot(Qt::Orientation)));
-#endif
+	connect(this,TQ_SIGNAL(orientationChanged(TQt::Orientation)),this,TQ_SLOT(orientationChangedSlot(TQt::Orientation)));
 }
 
 KviClassicTaskBar::~KviClassicTaskBar()
@@ -508,11 +466,9 @@ KviClassicTaskBar::~KviClassicTaskBar()
 	m_pButtonList = 0;
 }
 
-void KviClassicTaskBar::orientationChangedSlot(Qt::Orientation o)
+void KviClassicTaskBar::orientationChangedSlot(TQt::Orientation o)
 {
-#ifndef COMPILE_USE_QT4
-	if (orientation() == Qt::Horizontal) m_pBase->setMinimumHeight(m_iButtonHeight);
-#endif
+	if (orientation() == TQt::Horizontal) m_pBase->setMinimumHeight(m_iButtonHeight);
 	doLayout();
 }
 
@@ -655,30 +611,8 @@ void KviClassicTaskBar::doLayout()
 		totCount -= btnsInRow;
 	}
 
-#ifdef COMPILE_USE_QT4
-	if(isFloating() || ((g_pFrame->dockWidgetArea(this) != TQt::BottomDockWidgetArea) && (g_pFrame->dockWidgetArea(this) != TQt::TopDockWidgetArea)))
-	{
-		TQDockWidget::DockWidgetFeatures f = features();
-		if(f & TQDockWidget::DockWidgetVerticalTitleBar)
-		{
-			f &= ~TQDockWidget::DockWidgetVerticalTitleBar;
-			setFeatures(f);
-		}
-	} else {
-		TQDockWidget::DockWidgetFeatures f = features();
-		if(!(f & TQDockWidget::DockWidgetVerticalTitleBar))
-		{
-			f |= TQDockWidget::DockWidgetVerticalTitleBar;
-			setFeatures(f);
-		}
-	}
-#endif
 
-#ifdef COMPILE_USE_QT4
-	if ((width() > height()) && 
-#else
-	if ((orientation() == Qt::Horizontal) &&
-#endif
+	if ((orientation() == TQt::Horizontal) &&
 		(((unsigned int)rows) > m_pBase->height() / m_iButtonHeight ))
 	{
 		rows = m_pBase->height() / m_iButtonHeight;
@@ -709,11 +643,7 @@ void KviClassicTaskBar::doLayout()
 		}
 		
 		if( KVI_OPTION_BOOL(KviOption_boolClassicTaskBarSetMaximumButtonWidth) && (theWidth > KVI_OPTION_UINT(KviOption_uintClassicTaskBarMaximumButtonWidth)) &&
-#ifdef COMPILE_USE_QT4
-				(width() > height())
-#else
-				(orientation() == Qt::Horizontal)
-#endif
+				(orientation() == TQt::Horizontal)
 			)
 				theWidth = KVI_OPTION_UINT(KviOption_uintClassicTaskBarMaximumButtonWidth);
 
@@ -741,15 +671,6 @@ void KviClassicTaskBar::applyOptions()
 void KviClassicTaskBar::resizeEvent(TQResizeEvent *e)
 {
 /*
-#ifdef COMPILE_USE_QT4
-	if(orientation() == Qt::Horizontal)
-	{
-		int iRows = height()/m_iButtonHeight;
-		if(!iRows) iRows=1;
-		tqDebug("%i %i",height(),iRows);
-		resize(width(),iRows*m_iButtonHeight);
-	}
-#endif
 */
 	KviTaskBarBase::resizeEvent(e);
 	doLayout();
@@ -793,7 +714,7 @@ KviTreeTaskBarItem::KviTreeTaskBarItem(KviTalListView * par,KviWindow * wnd)
 	m_bIncreasing=0;
 	m_pInternal=new KviTreeTaskBarItemInternal(this);
 	m_pAnimTimer=new TQTimer();
-	TQObject::connect( m_pAnimTimer, TQT_SIGNAL(timeout()), m_pInternal, TQT_SLOT(timerShot()));
+	TQObject::connect( m_pAnimTimer, TQ_SIGNAL(timeout()), m_pInternal, TQ_SLOT(timerShot()));
 	applyOptions();
 }
 
@@ -804,7 +725,7 @@ KviTreeTaskBarItem::KviTreeTaskBarItem(KviTreeTaskBarItem * par,KviWindow * wnd)
 	m_bIncreasing=0;
 	m_pInternal=new KviTreeTaskBarItemInternal(this);
 	m_pAnimTimer=new TQTimer();
-	TQObject::connect( m_pAnimTimer, TQT_SIGNAL(timeout()), m_pInternal, TQT_SLOT(timerShot()));
+	TQObject::connect( m_pAnimTimer, TQ_SIGNAL(timeout()), m_pInternal, TQ_SLOT(timerShot()));
 	applyOptions();
 }
 
@@ -881,11 +802,7 @@ void KviTreeTaskBarItem::setActive(bool bActive)
 	}
 }
 
-#ifdef COMPILE_USE_QT4
-void KviTreeTaskBarItem::paintBranches(TQPainter *p,const TQColorGroup &,int w,int y,int h)
-#else
 void KviTreeTaskBarItem::paintBranches(TQPainter *p,const TQColorGroup &,int w,int y,int h,GUIStyle s)
-#endif
 {
 	SET_ANTI_ALIASING(*p);
 	((KviTreeTaskBarListView *)listView())->paintEmptyArea(p,TQRect(0,y,w,totalHeight() - height()));
@@ -1151,14 +1068,14 @@ void KviTreeTaskBarListView::contentsMousePressEvent(TQMouseEvent *e)
 	KviTalListViewItem * it = (KviTalListViewItem *)itemAt(contentsToViewport(e->pos()));
 	if(it)
 	{
-		if(e->button() & Qt::LeftButton)emit leftMousePress(it);
-		else if(e->button() & Qt::RightButton)emit rightMousePress(it);
+		if(e->button() & TQt::LeftButton)emit leftMousePress(it);
+		else if(e->button() & TQt::RightButton)emit rightMousePress(it);
 	} else {
-		if(e->button() & Qt::RightButton)
+		if(e->button() & TQt::RightButton)
 		{
 			KviTalPopupMenu* pPopup=new KviTalPopupMenu();
-			pPopup->insertItem(__tr2qs("Sort"),this,TQT_SLOT(sort()));
-			pPopup->insertItem(__tr2qs("Reverse Sort"),this,TQT_SLOT(reverseSort()));
+			pPopup->insertItem(__tr2qs("Sort"),this,TQ_SLOT(sort()));
+			pPopup->insertItem(__tr2qs("Reverse Sort"),this,TQ_SLOT(reverseSort()));
 			pPopup->popup(TQCursor::pos());
 		}
 	}
@@ -1222,14 +1139,10 @@ KviTreeTaskBar::KviTreeTaskBar()
 	m_pListView->setAllColumnsShowFocus(true);
 	m_pListView->setMultiSelection(false);
 
-#ifdef COMPILE_USE_QT4
-	setWidget(m_pListView);
-#else //!COMPILE_USE_QT4
 	setStretchableWidget(m_pListView);
 
 	setVerticalStretchable(true);
 	setHorizontalStretchable(true);
-#endif //!COMPILE_USE_QT4
 
 
 	// FIXME: this code is useless ?
@@ -1246,17 +1159,9 @@ KviTreeTaskBar::KviTreeTaskBar()
 	//setMaximumWidth(KVI_OPTION_UINT(KviOption_uintTreeTaskBarMaximumWidth));
 	//m_pListView->setMinimumWidth(KVI_OPTION_UINT(KviOption_uintTreeTaskBarMinimumWidth));
     //m_pListView->setMaximumWidth(KVI_OPTION_UINT(KviOption_uintTreeTaskBarMaximumWidth));
-#ifdef COMPILE_USE_QT4
-	m_pListView->setFocusPolicy(TQ_NoFocus);
-#else
-	m_pListView->setFocusPolicy(TQ_NoFocus);
-#endif
+	m_pListView->setFocusPolicy(TQWidget::NoFocus);
 	m_pListView->setStaticBackground(true);
-#ifdef COMPILE_USE_QT4
-	m_pListView->viewport()->setAutoFillBackground(false);
-#else
 	m_pListView->viewport()->setBackgroundMode(TQWidget::NoBackground);
-#endif
 	if(!KVI_OPTION_BOOL(KviOption_boolShowTreeTaskbarHeader))
 	{
 		m_pListView->header()->hide();
@@ -1264,18 +1169,13 @@ KviTreeTaskBar::KviTreeTaskBar()
 	
 	m_pListView->header()->setResizeEnabled(true);
 
-#ifdef COMPILE_USE_QT4
-	setMaximumWidth(600);
-#endif
 
 	m_pListView->viewport()->installEventFilter(this);
 
-#ifndef COMPILE_USE_QT4
     setResizeEnabled(true);
-#endif
 
 	m_pToolTip = new KviDynamicToolTip(m_pListView->viewport(),"tree_taskbar_tooltip");
-	connect(m_pToolTip,TQT_SIGNAL(tipRequest(KviDynamicToolTip *,const TQPoint &)),this,TQT_SLOT(tipRequest(KviDynamicToolTip *,const TQPoint &)));
+	connect(m_pToolTip,TQ_SIGNAL(tipRequest(KviDynamicToolTip *,const TQPoint &)),this,TQ_SLOT(tipRequest(KviDynamicToolTip *,const TQPoint &)));
 }
 
 KviTreeTaskBar::~KviTreeTaskBar()
@@ -1312,7 +1212,7 @@ void KviTreeTaskBar::tipRequest(KviDynamicToolTip *,const TQPoint &pnt)
 
 bool KviTreeTaskBar::eventFilter(TQObject * o,TQEvent *e)
 {
-	if(TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_pListView->viewport()))
+	if(o == m_pListView->viewport())
 	{
 		if(e->type() == TQEvent::MouseButtonPress)
 		{
@@ -1322,7 +1222,7 @@ bool KviTreeTaskBar::eventFilter(TQObject * o,TQEvent *e)
 			KviWindow * wnd = it->kviWindow();
 			if(wnd)
 			{
-				if(ev->button() & Qt::LeftButton)
+				if(ev->button() & TQt::LeftButton)
 				{
 					if(ev->state() & TQt::ShiftButton)
 					{
