@@ -98,7 +98,7 @@ KviTopicWidget::KviTopicWidget(TQWidget * par,const char * name)
 //	m_pCompletionBox->setHScrollBarMode( KviTalListBox::AlwaysOff );
 	m_pCompletionBox->setFrameStyle( TQFrame::Box | TQFrame::Plain );
 	m_pCompletionBox->setLineWidth( 1 );
-	connect(m_pCompletionBox,TQT_SIGNAL(selected(int)),this,TQT_SLOT(complete(int)));
+	connect(m_pCompletionBox,TQ_SIGNAL(selected(int)),this,TQ_SLOT(complete(int)));
 	m_pCompletionBox->hide();
 }
 
@@ -561,8 +561,8 @@ void KviTopicWidget::mouseDoubleClickEvent(TQMouseEvent *)
 		m_pInput->setMaxBufferSize(maxlen);
 		m_pInput->setGeometry(0,0,width() - (height() << 2)+height(),height());
 		m_pInput->setText(m_szTopic);
-		connect(m_pInput,TQT_SIGNAL(enterPressed()),this,TQT_SLOT(acceptClicked()));
-		connect(m_pInput,TQT_SIGNAL(escapePressed()),this,TQT_SLOT(discardClicked()));
+		connect(m_pInput,TQ_SIGNAL(enterPressed()),this,TQ_SLOT(acceptClicked()));
+		connect(m_pInput,TQ_SIGNAL(escapePressed()),this,TQ_SLOT(discardClicked()));
 		m_pInput->installEventFilter(this);
 
 		m_pHistory = new TQPushButton(this);
@@ -570,7 +570,7 @@ void KviTopicWidget::mouseDoubleClickEvent(TQMouseEvent *)
 		m_pHistory->setGeometry(width() - (height() << 2)+height(),0,height(),height());
 		KviTalToolTip::add(m_pHistory,__tr2qs("History"));
 		m_pHistory->show();
-		connect(m_pHistory,TQT_SIGNAL(clicked()),this,TQT_SLOT(historyClicked()));
+		connect(m_pHistory,TQ_SIGNAL(clicked()),this,TQ_SLOT(historyClicked()));
 		
 		m_pAccept = new TQPushButton(this);
 		m_pAccept->setPixmap(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_ACCEPT)));
@@ -578,14 +578,14 @@ void KviTopicWidget::mouseDoubleClickEvent(TQMouseEvent *)
 		m_pAccept->setEnabled(bCanEdit);
 		m_pAccept->show();
 		KviTalToolTip::add(m_pAccept,__tr2qs("Commit Changes"));
-		connect(m_pAccept,TQT_SIGNAL(clicked()),this,TQT_SLOT(acceptClicked()));
+		connect(m_pAccept,TQ_SIGNAL(clicked()),this,TQ_SLOT(acceptClicked()));
 		
 		m_pDiscard = new TQPushButton(this);
 		m_pDiscard->setPixmap(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_DISCARD)));
 		m_pDiscard->setGeometry(width() - height(),0,height(),height());
 		KviTalToolTip::add(m_pDiscard,__tr2qs("Discard Changes"));
 		m_pDiscard->show();
-		connect(m_pDiscard,TQT_SIGNAL(clicked()),this,TQT_SLOT(discardClicked()));
+		connect(m_pDiscard,TQ_SIGNAL(clicked()),this,TQ_SLOT(discardClicked()));
 		
 		m_pInput->show();
 		m_pInput->setFocus();
@@ -595,11 +595,11 @@ void KviTopicWidget::mouseDoubleClickEvent(TQMouseEvent *)
 void KviTopicWidget::mousePressEvent(TQMouseEvent * e)
 {
 
-	if(!(e->button() & Qt::RightButton))return;
+	if(!(e->button() & TQt::RightButton))return;
 	if(!m_pContextPopup)
 	{
 		m_pContextPopup = new KviTalPopupMenu(this);
-		connect(m_pContextPopup,TQT_SIGNAL(aboutToShow()),this,TQT_SLOT(contextPopupAboutToShow()));
+		connect(m_pContextPopup,TQ_SIGNAL(aboutToShow()),this,TQ_SLOT(contextPopupAboutToShow()));
 	}
 	m_pContextPopup->popup(mapToGlobal(e->pos()));
 }
@@ -608,7 +608,7 @@ void KviTopicWidget::contextPopupAboutToShow()
 {
 	if(!m_pContextPopup)return; // hm ?
 	m_pContextPopup->clear();
-	m_pContextPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_COPY)),__tr2qs("Copy to clipboard"),this,TQT_SLOT(copy()));
+	m_pContextPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_COPY)),__tr2qs("Copy to clipboard"),this,TQ_SLOT(copy()));
 }
 
 void KviTopicWidget::copy()
