@@ -210,7 +210,7 @@ KviAliasEditor::KviAliasEditor(TQWidget * par)
 
 	TQGridLayout * l = new TQGridLayout(this,1,1,2,2);
 
-	m_pSplitter = new TQSplitter(Qt::Horizontal,this);
+	m_pSplitter = new TQSplitter(TQt::Horizontal,this);
 
 	l->addWidget(m_pSplitter,0,0);
 	
@@ -226,13 +226,13 @@ KviAliasEditor::KviAliasEditor(TQWidget * par)
 	m_pNameLabel = new TQLabel(__tr2qs("No item selected"),hbox);
 	m_pRenameButton = new TQPushButton(__tr2qs("Rename"),hbox);
 	m_pRenameButton->setEnabled(false);
-	connect(m_pRenameButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(renameItem()));
+	connect(m_pRenameButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(renameItem()));
 	hbox->setStretchFactor(m_pNameLabel,2);
 	TQToolTip::add(m_pRenameButton,__tr2qs("Edit the alias or namespace name"));
 	m_pEditor = KviScriptEditor::createInstance(box);
 	m_pEditor->setFocus();
-	connect(m_pEditor,TQT_SIGNAL(find(const TQString &)),this,TQT_SLOT(slotFindWord(const TQString &)));
-	connect(m_pEditor,TQT_SIGNAL(replaceAll(const TQString &,const TQString &)),this,TQT_SLOT(slotReplaceAll(const TQString &,const TQString &)));
+	connect(m_pEditor,TQ_SIGNAL(find(const TQString &)),this,TQ_SLOT(slotFindWord(const TQString &)));
+	connect(m_pEditor,TQ_SIGNAL(replaceAll(const TQString &,const TQString &)),this,TQ_SLOT(slotReplaceAll(const TQString &,const TQString &)));
 
 	m_pContextPopup = new KviTalPopupMenu(this);
 
@@ -380,9 +380,9 @@ void KviAliasEditor::oneTimeSetup()
 		++it;
 	}
 		
-	connect(m_pListView,TQT_SIGNAL(currentChanged(KviTalListViewItem *)),this,TQT_SLOT(currentItemChanged(KviTalListViewItem *)));
-	connect(m_pListView,TQT_SIGNAL(rightButtonPressed(KviTalListViewItem *,const TQPoint &,int)),
-		this,TQT_SLOT(itemPressed(KviTalListViewItem *,const TQPoint &,int)));
+	connect(m_pListView,TQ_SIGNAL(currentChanged(KviTalListViewItem *)),this,TQ_SLOT(currentItemChanged(KviTalListViewItem *)));
+	connect(m_pListView,TQ_SIGNAL(rightButtonPressed(KviTalListViewItem *,const TQPoint &,int)),
+		this,TQ_SLOT(itemPressed(KviTalListViewItem *,const TQPoint &,int)));
 }
 
 bool KviAliasEditor::hasSelectedItems(KviTalListViewItem * it)
@@ -417,12 +417,12 @@ void KviAliasEditor::itemPressed(KviTalListViewItem *it,const TQPoint &pnt,int c
 	m_pContextPopup->insertItem(
 			*(g_pIconManager->getSmallIcon(KVI_SMALLICON_ALIAS)),
 			__tr2qs("Add Alias"),
-			this,TQT_SLOT(newAlias()));
+			this,TQ_SLOT(newAlias()));
 
 	m_pContextPopup->insertItem(
 			*(g_pIconManager->getSmallIcon(KVI_SMALLICON_ALIAS)),
 			__tr2qs("Add Namespace"),
-			this,TQT_SLOT(newNamespace()));
+			this,TQ_SLOT(newNamespace()));
 	
 
 	bool bHasItems = m_pListView->firstChild() != 0;
@@ -433,7 +433,7 @@ void KviAliasEditor::itemPressed(KviTalListViewItem *it,const TQPoint &pnt,int c
 	id = m_pContextPopup->insertItem(
 			*(g_pIconManager->getSmallIcon(KVI_SMALLICON_QUIT)),
 			__tr2qs("Remove Selected"),
-			this,TQT_SLOT(removeSelectedItems()));
+			this,TQ_SLOT(removeSelectedItems()));
 	m_pContextPopup->setItemEnabled(id,bHasSelected);
 
 
@@ -442,20 +442,20 @@ void KviAliasEditor::itemPressed(KviTalListViewItem *it,const TQPoint &pnt,int c
 	m_pContextPopup->insertItem(
 			*(g_pIconManager->getSmallIcon(KVI_SMALLICON_FOLDER)),
 			__tr2qs("Export Selected..."),
-			this,TQT_SLOT(exportSelected()));
+			this,TQ_SLOT(exportSelected()));
 	m_pContextPopup->setItemEnabled(id,bHasSelected);
 
 	m_pContextPopup->insertItem(
 			*(g_pIconManager->getSmallIcon(KVI_SMALLICON_FOLDER)),
 			__tr2qs("Export Selected in singles files..."),
-			this,TQT_SLOT(exportSelectedSepFiles()));
+			this,TQ_SLOT(exportSelectedSepFiles()));
 
 	m_pContextPopup->setItemEnabled(id,bHasSelected);
 
 	m_pContextPopup->insertItem(
 			*(g_pIconManager->getSmallIcon(KVI_SMALLICON_FOLDER)),
 			__tr2qs("Export All..."),
-			this,TQT_SLOT(exportAll()));
+			this,TQ_SLOT(exportAll()));
 	m_pContextPopup->setItemEnabled(id,bHasItems);
 
 	m_pContextPopup->insertSeparator();
@@ -463,13 +463,13 @@ void KviAliasEditor::itemPressed(KviTalListViewItem *it,const TQPoint &pnt,int c
 	m_pContextPopup->insertItem(
 			*(g_pIconManager->getSmallIcon(KVI_SMALLICON_SEARCH)),
 			__tr2qs("Find In Aliases..."),
-			this,TQT_SLOT(slotFind()));
+			this,TQ_SLOT(slotFind()));
 	m_pContextPopup->setItemEnabled(id,bHasItems);
 
 	m_pContextPopup->insertItem(
 			*(g_pIconManager->getSmallIcon(KVI_SMALLICON_NAMESPACE)),
 			__tr2qs("Collapse All Namespaces"),
-			this,TQT_SLOT(slotCollapseNamespaces()));
+			this,TQ_SLOT(slotCollapseNamespaces()));
 
 	m_pContextPopup->setItemEnabled(id,bHasItems);
 
@@ -1332,17 +1332,17 @@ KviAliasEditorWindow::KviAliasEditorWindow(KviFrame * lpFrm)
 	TQGridLayout * g = new TQGridLayout(m_pBase,1,4,4,4);
 
 	TQPushButton * btn = new TQPushButton(__tr2qs("&OK"),m_pBase);
-	connect(btn,TQT_SIGNAL(clicked()),this,TQT_SLOT(okClicked()));
+	connect(btn,TQ_SIGNAL(clicked()),this,TQ_SLOT(okClicked()));
 	btn->setIconSet(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_ACCEPT)));
 	g->addWidget(btn,0,1);
 
 	btn = new TQPushButton(__tr2qs("&Apply"),m_pBase);
-	connect(btn,TQT_SIGNAL(clicked()),this,TQT_SLOT(applyClicked()));
+	connect(btn,TQ_SIGNAL(clicked()),this,TQ_SLOT(applyClicked()));
 	btn->setIconSet(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_ACCEPT)));
 	g->addWidget(btn,0,2);
 
 	btn = new TQPushButton(__tr2qs("Cancel"),m_pBase);
-	connect(btn,TQT_SIGNAL(clicked()),this,TQT_SLOT(cancelClicked()));
+	connect(btn,TQ_SIGNAL(clicked()),this,TQ_SLOT(cancelClicked()));
 	btn->setIconSet(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_DISCARD)));
 	g->addWidget(btn,0,3);
 
