@@ -94,10 +94,10 @@ const int align_cod[] = {
 		!fn: $setAlignment(<alignment:string>)
 		Set the alignment of the groupbox;  Valid values are Left,Right,HCenter.
 		!fn: $setOrientation<orientation:string>
-		Sets the group box's orientation. Valid values are:Qt::Horizontal,Qt::Vertical.
+		Sets the group box's orientation. Valid values are Horizontal,Vertical.
 		!fn: $setColumnLayout(<columns:integer>,<orientation:string>)
 		Enables the automatic layout management. The children are arranged in n columns with the specified orientation.[br]
-		Valid values for <orientation> are:Qt::Horizontal,Qt::Vertical.
+		Valid values for <orientation> are Horizontal,Vertical.
 	@examples:
 		[example]
 		|-Start:[br]
@@ -184,7 +184,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_groupbox)
 
 bool KviKvsObject_groupbox::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
 {
-	setObject(TQT_TQOBJECT(new KviTalGroupBox(name(),parentScriptWidget())), true);
+	setObject(new KviTalGroupBox(name(),parentScriptWidget()), true);
 	return true;
 }
 
@@ -342,10 +342,10 @@ bool KviKvsObject_groupbox::functionSetOrientation(KviKvsObjectFunctionCall *c)
 	KVSO_PARAMETERS_END(c)
 	if(!widget())return true;
 	if(KviTQString::equalCI(szMode, "Horizontal"))
-		((KviTalGroupBox *)widget())->setOrientation(Qt::Horizontal);
+		((KviTalGroupBox *)widget())->setOrientation(TQt::Horizontal);
 	else
 	if(KviTQString::equalCI(szMode, "Vertical"))
-		((KviTalGroupBox *)widget())->setOrientation(Qt::Vertical);
+		((KviTalGroupBox *)widget())->setOrientation(TQt::Vertical);
 	else c->warning( __tr2qs("Unknown orientation: "));
 	return true;
 }
@@ -360,10 +360,10 @@ bool KviKvsObject_groupbox::functionSetColumnLayout(KviKvsObjectFunctionCall *c)
 	KVSO_PARAMETERS_END(c)
 	if(!widget())return true;
 	if(szMode=="Horizontal")
-		((KviTalGroupBox *)widget())->setColumnLayout(uCol,Qt::Horizontal);
+		((KviTalGroupBox *)widget())->setColumnLayout(uCol,TQt::Horizontal);
 	else
 		if(szMode=="Vertical")
-			((KviTalGroupBox *)widget())->setColumnLayout(uCol,Qt::Vertical);
+			((KviTalGroupBox *)widget())->setColumnLayout(uCol,TQt::Vertical);
 		else c->warning( __tr2qs("Unknown orientation: "));
 	return true;
 }
