@@ -212,18 +212,18 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_listview)
 
 bool KviKvsObject_listview::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
 {
-	setObject(TQT_TQOBJECT(new KviKvsMdmListView(parentScriptWidget(),name(),this)),true);
-	connect(widget(),TQT_SIGNAL(clicked(KviTalListViewItem *)),this,TQT_SLOT(slotClicked(KviTalListViewItem *)));
-	connect(widget(),TQT_SIGNAL(selectionChanged(KviTalListViewItem *)),this,TQT_SLOT(slotSelectionChanged(KviTalListViewItem *)));
-	connect(widget(),TQT_SIGNAL(selectionChanged()),this,TQT_SLOT(slotMultipleSelectionChanged()));
-	connect(widget(),TQT_SIGNAL(currentChanged(KviTalListViewItem *)),this,TQT_SLOT(slotCurrentChanged(KviTalListViewItem *)));
-	connect(widget(),TQT_SIGNAL(returnPressed(KviTalListViewItem *)),this,TQT_SLOT(slotReturnPressed(KviTalListViewItem *)));
-	connect(widget(),TQT_SIGNAL(spacePressed(KviTalListViewItem *)),this,TQT_SLOT(slotSpacePressed(KviTalListViewItem *)));
-	connect(widget(),TQT_SIGNAL(onItem(KviTalListViewItem *)),this,TQT_SLOT(slotOnItem(KviTalListViewItem *)));
-	connect(widget(),TQT_SIGNAL(expanded(KviTalListViewItem *)),this,TQT_SLOT(slotItemExpanded(KviTalListViewItem *)));
-	connect(widget(),TQT_SIGNAL(collapsed(KviTalListViewItem *)),this,TQT_SLOT(slotItemCollapsed(KviTalListViewItem *)));
-	connect(widget(),TQT_SIGNAL(rightButtonClicked(KviTalListViewItem *,const TQPoint &,int)),this,TQT_SLOT(slotRightButtonClicked(KviTalListViewItem *,const TQPoint &,int)));
-	connect(widget(),TQT_SIGNAL(itemRenamed(KviTalListViewItem *,int,const TQString &)),this,TQT_SLOT(slotItemRenamed(KviTalListViewItem *,int,const TQString &)));
+	setObject(new KviKvsMdmListView(parentScriptWidget(),name(),this),true);
+	connect(widget(),TQ_SIGNAL(clicked(KviTalListViewItem *)),this,TQ_SLOT(slotClicked(KviTalListViewItem *)));
+	connect(widget(),TQ_SIGNAL(selectionChanged(KviTalListViewItem *)),this,TQ_SLOT(slotSelectionChanged(KviTalListViewItem *)));
+	connect(widget(),TQ_SIGNAL(selectionChanged()),this,TQ_SLOT(slotMultipleSelectionChanged()));
+	connect(widget(),TQ_SIGNAL(currentChanged(KviTalListViewItem *)),this,TQ_SLOT(slotCurrentChanged(KviTalListViewItem *)));
+	connect(widget(),TQ_SIGNAL(returnPressed(KviTalListViewItem *)),this,TQ_SLOT(slotReturnPressed(KviTalListViewItem *)));
+	connect(widget(),TQ_SIGNAL(spacePressed(KviTalListViewItem *)),this,TQ_SLOT(slotSpacePressed(KviTalListViewItem *)));
+	connect(widget(),TQ_SIGNAL(onItem(KviTalListViewItem *)),this,TQ_SLOT(slotOnItem(KviTalListViewItem *)));
+	connect(widget(),TQ_SIGNAL(expanded(KviTalListViewItem *)),this,TQ_SLOT(slotItemExpanded(KviTalListViewItem *)));
+	connect(widget(),TQ_SIGNAL(collapsed(KviTalListViewItem *)),this,TQ_SLOT(slotItemCollapsed(KviTalListViewItem *)));
+	connect(widget(),TQ_SIGNAL(rightButtonClicked(KviTalListViewItem *,const TQPoint &,int)),this,TQ_SLOT(slotRightButtonClicked(KviTalListViewItem *,const TQPoint &,int)));
+	connect(widget(),TQ_SIGNAL(itemRenamed(KviTalListViewItem *,int,const TQString &)),this,TQ_SLOT(slotItemRenamed(KviTalListViewItem *,int,const TQString &)));
 	return true;
 }
 
