@@ -340,7 +340,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_mledit)
 
 bool KviKvsObject_mledit::init(KviKvsRunTimeContext * pContext,KviKvsVariantList * pParams)
 {
-	setObject(TQT_TQOBJECT(new KviTalMultiLineEdit(parentScriptWidget(),getName())),true);
+	setObject(new KviTalMultiLineEdit(parentScriptWidget(),getName()),true);
 	return true;
 }
 
