@@ -528,8 +528,8 @@ bool KviKvsObject_painter::functionsetBackGroundMode(KviKvsObjectFunctionCall *c
 		KVSO_PARAMETER("background mode",KVS_PT_STRING,0,szMode)
 	KVSO_PARAMETERS_END(c)
 	if(!m_pPainter)return true;
-	if(KviTQString::equalCI(szMode,"Transparent")) m_pPainter->setBackgroundMode(Qt::TransparentMode);
-	else if(KviTQString::equalCI(szMode,"Opaque")) m_pPainter->setBackgroundMode(Qt::OpaqueMode);
+	if(KviTQString::equalCI(szMode,"Transparent")) m_pPainter->setBackgroundMode(TQt::TransparentMode);
+	else if(KviTQString::equalCI(szMode,"Opaque")) m_pPainter->setBackgroundMode(TQt::OpaqueMode);
 	else c->warning( __tr2qs("Unknown orientation"));
 	return true;
 	
@@ -771,8 +771,8 @@ bool KviKvsObject_painter::functionbegin(KviKvsObjectFunctionCall *c)
 	}
 
 	TQPaintDevice * pd = 0;
-	if(pObject->inherits("KviKvsObject_pixmap"))pd =TQT_TQPAINTDEVICE(((KviKvsObject_pixmap *)pObject)->getPixmap());
-	else if (pObject->inherits("KviKvsObject_widget")) pd=TQT_TQPAINTDEVICE(((KviKvsObject_widget *)pObject)->widget());
+	if(pObject->inherits("KviKvsObject_pixmap"))pd =((KviKvsObject_pixmap *)pObject)->getPixmap();
+	else if (pObject->inherits("KviKvsObject_widget")) pd=((KviKvsObject_widget *)pObject)->widget();
 	
 	if (!pd)
 		c->warning(__tr2qs("Widget or Pixmap required "));
@@ -792,7 +792,7 @@ void KviKvsObject_painter::attachDevice(KviKvsObject * o,TQPaintDevice * p)
 	// it is emitted BEFORE the real TQPaintDevice is deleted, so we can eventually
 	// call m_pPainter->end() in time
 
-	TQObject::connect(m_pDeviceObject,TQT_SIGNAL(aboutToDie()),this,TQT_SLOT(detachDevice()));
+	TQObject::connect(m_pDeviceObject,TQ_SIGNAL(aboutToDie()),this,TQ_SLOT(detachDevice()));
 	m_pPainter->begin(p);
 }
 
@@ -800,7 +800,7 @@ void KviKvsObject_painter::detachDevice()
 {
 	if(!m_pDeviceObject)return;
 	if(!m_pPainter)return;
-	disconnect(m_pDeviceObject,TQT_SIGNAL(aboutToDie()),this,TQT_SLOT(detachDevice()));
+	disconnect(m_pDeviceObject,TQ_SIGNAL(aboutToDie()),this,TQ_SLOT(detachDevice()));
 	m_pPainter->end();
 	m_pDeviceObject = 0;
 }
