@@ -132,8 +132,8 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_spinbox)
 
 bool KviKvsObject_spinbox::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
 {
-	setObject(TQT_TQOBJECT(new TQSpinBox(parentScriptWidget(), name())), true);
-	connect(widget(),TQT_SIGNAL(valueChanged(int)),this,TQT_SLOT(valueChanged(int)));
+	setObject(new TQSpinBox(parentScriptWidget(), name()), true);
+	connect(widget(),TQ_SIGNAL(valueChanged(int)),this,TQ_SLOT(valueChanged(int)));
 	return true;
 }
 
