@@ -184,7 +184,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_workspace)
 
 bool KviKvsObject_workspace::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
 {
-	setObject(TQT_TQOBJECT(new TQWorkspace(parentScriptWidget(), name())), true);
+	setObject(new TQWorkspace(parentScriptWidget(), name()), true);
 	return true;
 }
 
