@@ -213,7 +213,7 @@ static bool options_kvs_cmd_edit(KviKvsModuleCommandCall * c)
 
 	if(c->hasSwitch('m',"modal"))
 	{
-		w = TQT_TQWIDGET(g_pApp->activeModalWidget());
+		w = g_pApp->activeModalWidget();
 		if(!w)w = g_pFrame;
 	} else {
 		w = g_pFrame;
@@ -228,7 +228,7 @@ static bool options_kvs_cmd_edit(KviKvsModuleCommandCall * c)
 	{
 		if(g_pSplashScreen->isVisible()) // another bug: this ALWAYS RETURNS TRUE, even if the splash was hidden by a mouse click...
 		{
-			TQObject::connect(g_pSplashScreen,TQT_SIGNAL(destroyed()),wc,TQT_SLOT(show()));
+			TQObject::connect(g_pSplashScreen,TQ_SIGNAL(destroyed()),wc,TQ_SLOT(show()));
 			return true;
 		}
 	}
