@@ -79,7 +79,7 @@ KviSetupPage::KviSetupPage(KviSetupWizard * w)
 
 	//setBackgroundColor(TQColor(255,0,0));
 
-	// we need this to set localized text on buttons (see QT doc/ KviTalWizard class)
+	// we need this to set localized text on buttons (see TQt doc/ KviTalWizard class)
 	w->KviTalWizard::backButton()->setText(__tr2qs("< &Back"));
 	w->KviTalWizard::nextButton()->setText(__tr2qs("&Next >"));
 	w->KviTalWizard::finishButton()->setText(__tr2qs("Finish"));
@@ -231,19 +231,19 @@ KviSetupWizard::KviSetupWizard()
 
 	m_pDirButtonGroup = new KviTalVButtonGroup(__tr2qs("Store configuration in folder"),m_pDirectory->m_pVBox);
 	m_pDirUsePrev = new TQRadioButton(__tr2qs("Use settings folder from previous installation"),m_pDirButtonGroup);
-	connect(m_pDirUsePrev,TQT_SIGNAL(clicked()),this,TQT_SLOT(oldDirClicked()));
+	connect(m_pDirUsePrev,TQ_SIGNAL(clicked()),this,TQ_SLOT(oldDirClicked()));
 	
 	m_pOldPathBox = new KviTalHBox(m_pDirButtonGroup);
 	m_pOldDataPathEdit = new TQLineEdit(m_pOldPathBox);
-	connect(m_pOldDataPathEdit,TQT_SIGNAL(textChanged ( const TQString & )),this,TQT_SLOT(oldDataTextChanged ( const TQString & )));
+	connect(m_pOldDataPathEdit,TQ_SIGNAL(textChanged ( const TQString & )),this,TQ_SLOT(oldDataTextChanged ( const TQString & )));
 	
 	TQPushButton * pb = new TQPushButton(__tr2qs("&Browse..."),m_pOldPathBox);
-	connect(pb,TQT_SIGNAL(clicked()),this,TQT_SLOT(chooseOldDataPath()));
+	connect(pb,TQ_SIGNAL(clicked()),this,TQ_SLOT(chooseOldDataPath()));
 	m_pOldPathBox->setSpacing(3);
 	m_pOldPathBox->setStretchFactor(m_pOldDataPathEdit,1);
 	
 	m_pDirUseNew = new TQRadioButton(__tr2qs("Use new settings folder"),m_pDirButtonGroup);
-	connect(m_pDirUseNew,TQT_SIGNAL(clicked()),this,TQT_SLOT(newDirClicked()));
+	connect(m_pDirUseNew,TQ_SIGNAL(clicked()),this,TQ_SLOT(newDirClicked()));
 	
 	TQLabel* l = new TQLabel(m_pDirButtonGroup);
 	l->setText(__tr2qs("Settings folder:"));
@@ -252,7 +252,7 @@ KviSetupWizard::KviSetupWizard()
 	m_pDataPathEdit = new TQLineEdit(m_pNewPathBox);
 	
 	pb = new TQPushButton(__tr2qs("&Browse..."),m_pNewPathBox);
-	connect(pb,TQT_SIGNAL(clicked()),this,TQT_SLOT(chooseDataPath()));
+	connect(pb,TQ_SIGNAL(clicked()),this,TQ_SLOT(chooseDataPath()));
 
 	m_pNewPathBox->setSpacing(3);
 	m_pNewPathBox->setStretchFactor(m_pDataPathEdit,1);
@@ -280,7 +280,7 @@ KviSetupWizard::KviSetupWizard()
 	m_pIncomingPathEdit = new TQLineEdit(m_pNewIncomingBox);
 	
 	pb = new TQPushButton(__tr2qs("&Browse..."),m_pNewIncomingBox);
-	connect(pb,TQT_SIGNAL(clicked()),this,TQT_SLOT(chooseIncomingPath()));
+	connect(pb,TQ_SIGNAL(clicked()),this,TQ_SLOT(chooseIncomingPath()));
 
 	m_pNewIncomingBox->setSpacing(3);
 	m_pNewIncomingBox->setStretchFactor(m_pIncomingPathEdit,1);
@@ -308,8 +308,8 @@ KviSetupWizard::KviSetupWizard()
 
 	setHelpEnabled(m_pDirectory,false);
 
-	connect(m_pDataPathEdit,TQT_SIGNAL(textChanged ( const TQString & )),this,TQT_SLOT(newDataTextChanged ( const TQString & )));
-	connect(m_pIncomingPathEdit,TQT_SIGNAL(textChanged ( const TQString & )),this,TQT_SLOT(newIncomingTextChanged ( const TQString & )));
+	connect(m_pDataPathEdit,TQ_SIGNAL(textChanged ( const TQString & )),this,TQ_SLOT(newDataTextChanged ( const TQString & )));
+	connect(m_pIncomingPathEdit,TQ_SIGNAL(textChanged ( const TQString & )),this,TQ_SLOT(newIncomingTextChanged ( const TQString & )));
 
 	/////////////////////////////////////////////////////////////////////////////////////////////////////////////
 	// Identity
@@ -331,12 +331,12 @@ KviSetupWizard::KviSetupWizard()
 	if(nick == "root")nick = "newbie";
 //m_pIdentity->m_pVBox
 //__tr2qs("Basic Properties")
-	KviTalGroupBox * gbox = new KviTalGroupBox(1,Qt::Horizontal,TQString(),m_pIdentity->m_pVBox);
+	KviTalGroupBox * gbox = new KviTalGroupBox(1,TQt::Horizontal,TQString(),m_pIdentity->m_pVBox);
 
 	m_pNickSelector = new KviStringSelector(gbox,__tr2qs("Nickname:"),&(KVI_OPTION_STRING(KviOption_stringNickname1)),true);
 	m_pNickSelector->setMinimumLabelWidth(120);
 	
-	TQValidator * v = new TQRegExpValidator(TQRegExp("[^-0-9 ][^ ]*"),TQT_TQOBJECT(gbox));
+	TQValidator * v = new TQRegExpValidator(TQRegExp("[^-0-9 ][^ ]*"),gbox);
 	m_pNickSelector->setValidator(v);
 
 	TQString szOptionalCtcpUserInfo = __tr2qs("This field is optional and will appear as part of the CTCP USERINFO reply.");
@@ -344,7 +344,7 @@ KviSetupWizard::KviSetupWizard()
 	TQString szCenterEnd("</center>");
 	TQString szTrailing = "<br><br>" + szOptionalCtcpUserInfo + szCenterEnd;
 
-	gbox = new KviTalGroupBox(1,Qt::Horizontal,__tr2qs("Profile"),m_pIdentity->m_pVBox);
+	gbox = new KviTalGroupBox(1,TQt::Horizontal,__tr2qs("Profile"),m_pIdentity->m_pVBox);
 
 	m_pRealNameSelector = new KviStringSelector(gbox,__tr2qs("Real name:"),&(KVI_OPTION_STRING(KviOption_stringRealname)),true);
 	m_pRealNameSelector->setMinimumLabelWidth(120);
@@ -728,7 +728,7 @@ void KviSetupWizard::chooseOldDataPath()
 				TQMessageBox::question(
 				this,
 				__tr2qs("Do not overwrite folder? - KVIrc"),
-				tqtr("A folder %1 seems to be not a valid KVIrc settings folder."
+				tr("A folder %1 seems to be not a valid KVIrc settings folder."
 					"Do you want to use it anyway?")
 					.arg( szBuffer ),
 				__tr2qs("&Yes"), __tr2qs("&No"),
